lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [lmi] master a06f6e9: Rename: {paste out, paste in} --> {c


From: Greg Chicares
Subject: [lmi-commits] [lmi] master a06f6e9: Rename: {paste out, paste in} --> {copy, paste}
Date: Tue, 19 Jun 2018 16:13:52 -0400 (EDT)

branch: master
commit a06f6e9fc2fc0052eecf639a2c50633ee83b5cab
Author: Gregory W. Chicares <address@hidden>
Commit: Gregory W. Chicares <address@hidden>

    Rename: {paste out, paste in} --> {copy, paste}
---
 README                                 |   4 ++--
 census_view.cpp                        |  38 ++++++++++++++++-----------------
 census_view.hpp                        |   6 +++---
 paste-out-16.png => copy-census-16.png | Bin
 paste-out.png => copy-census.png       | Bin
 gpt_view.cpp                           |   4 ++--
 icon_monger.cpp                        |   4 ++--
 illustration_view.cpp                  |   4 ++--
 mec_view.cpp                           |   4 ++--
 menus.xrc                              |  18 ++++++++--------
 paste-in-16.png => paste-census-16.png | Bin
 paste-in.png => paste-census.png       | Bin
 skeleton.cpp                           |   4 ++--
 toolbar.xrc                            |  18 ++++++++--------
 14 files changed, 52 insertions(+), 52 deletions(-)

diff --git a/README b/README
index cd7867f..c3bb05b 100644
--- a/README
+++ b/README
@@ -33,6 +33,7 @@ sizes 24x24 and 16x16:
   close[-16].png                    from stock_close.png
   copy[-16].png                     from stock_copy.png
   copy-cell[-16].png                from stock_copy.png
+  copy-census[-16].png              from stock_paste.png
   default-cell[-16].png             from stock_new.png
   delete-row[-16].png               from stock_delete-row.png
   edit-case[-16].png                from stock_zoom.png
@@ -44,8 +45,7 @@ sizes 24x24 and 16x16:
   insert-rows[-16].png              from stock_insert-rows.png
   new[-16].png                      from stock_new.png
   open[-16].png                     from stock_open.png
-  paste-in[-16].png                 from stock_paste.png
-  paste-out[-16].png                from stock_paste.png
+  paste-census[-16].png             from stock_paste.png
   preferences[-16].png              from gnome-settings.png
   print-case[-16].png               from stock_print.png
   print-case-pdf[-16].png           from stock_print.png
diff --git a/census_view.hpp b/census_view.hpp
index 2d5f33c..977e33f 100644
--- a/census_view.hpp
+++ b/census_view.hpp
@@ -78,8 +78,8 @@ class CensusView final
     void UponRunCaseToSpreadsheet   (wxCommandEvent&);
     void UponRunCaseToGroupRoster   (wxCommandEvent&);
     void UponRunCaseToGroupQuote    (wxCommandEvent&);
-    void UponPasteCensusIn          (wxCommandEvent&);
-    void UponPasteCensusOut         (wxCommandEvent&);
+    void UponCopyCensus             (wxCommandEvent&);
+    void UponPasteCensus            (wxCommandEvent&);
     void UponAddCell                (wxCommandEvent&);
     void UponDeleteCells            (wxCommandEvent&);
     void UponColumnWidthVarying     (wxCommandEvent&);
@@ -125,7 +125,7 @@ class CensusView final
 
     void update_class_names();
 
-    void DoPasteCensusOut() const;
+    void DoCopyCensus() const;
 
     bool autosize_columns_;
 
diff --git a/paste-out-16.png b/copy-census-16.png
similarity index 100%
rename from paste-out-16.png
rename to copy-census-16.png
diff --git a/paste-out.png b/copy-census.png
similarity index 100%
rename from paste-out.png
rename to copy-census.png
diff --git a/gpt_view.cpp b/gpt_view.cpp
index 74fa4c4..95d6f52 100644
--- a/gpt_view.cpp
+++ b/gpt_view.cpp
@@ -70,8 +70,8 @@ BEGIN_EVENT_TABLE(gpt_view, ViewEx)
     EVT_UPDATE_UI(XRCID("print_spreadsheet"    
),gpt_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("print_group_roster"   
),gpt_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("print_group_quote"    
),gpt_view::UponUpdateInapplicable)
-    EVT_UPDATE_UI(XRCID("paste_census_in"      
),gpt_view::UponUpdateInapplicable)
-    EVT_UPDATE_UI(XRCID("paste_census_out"     
),gpt_view::UponUpdateInapplicable)
+    EVT_UPDATE_UI(XRCID("copy_census"          
),gpt_view::UponUpdateInapplicable)
+    EVT_UPDATE_UI(XRCID("paste_census"         
),gpt_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("add_cell"             
),gpt_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("delete_cells"         
),gpt_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("column_width_varying" 
),gpt_view::UponUpdateInapplicable)
diff --git a/icon_monger.cpp b/icon_monger.cpp
index 9e8d5ff..14a7ccb 100644
--- a/icon_monger.cpp
+++ b/icon_monger.cpp
@@ -80,13 +80,13 @@ icon_monger::icon_monger()
 
     // Non-stock icons.
     lmi_specific_icon_names_.insert("copy-cell"               );
+    lmi_specific_icon_names_.insert("copy-census"             );
     lmi_specific_icon_names_.insert("default-cell"            );
     lmi_specific_icon_names_.insert("edit-case"               );
     lmi_specific_icon_names_.insert("edit-cell"               );
     lmi_specific_icon_names_.insert("edit-class"              );
     lmi_specific_icon_names_.insert("fixed-width"             );
-    lmi_specific_icon_names_.insert("paste-in"                );
-    lmi_specific_icon_names_.insert("paste-out"               );
+    lmi_specific_icon_names_.insert("paste-census"            );
     lmi_specific_icon_names_.insert("preferences"             );
     lmi_specific_icon_names_.insert("print-case"              );
     lmi_specific_icon_names_.insert("print-case-pdf"          );
diff --git a/illustration_view.cpp b/illustration_view.cpp
index 4c71b3c..b5325c8 100644
--- a/illustration_view.cpp
+++ b/illustration_view.cpp
@@ -90,8 +90,8 @@ BEGIN_EVENT_TABLE(IllustrationView, ViewEx)
     EVT_UPDATE_UI(XRCID("print_spreadsheet"    
),IllustrationView::UponUpdateInapplicable )
     EVT_UPDATE_UI(XRCID("print_group_roster"   
),IllustrationView::UponUpdateInapplicable )
     EVT_UPDATE_UI(XRCID("print_group_quote"    
),IllustrationView::UponUpdateInapplicable )
-    EVT_UPDATE_UI(XRCID("paste_census_in"      
),IllustrationView::UponUpdateInapplicable )
-    EVT_UPDATE_UI(XRCID("paste_census_out"     
),IllustrationView::UponUpdateInapplicable )
+    EVT_UPDATE_UI(XRCID("copy_census"          
),IllustrationView::UponUpdateInapplicable )
+    EVT_UPDATE_UI(XRCID("paste_census"         
),IllustrationView::UponUpdateInapplicable )
     EVT_UPDATE_UI(XRCID("add_cell"             
),IllustrationView::UponUpdateInapplicable )
     EVT_UPDATE_UI(XRCID("delete_cells"         
),IllustrationView::UponUpdateInapplicable )
     EVT_UPDATE_UI(XRCID("column_width_varying" 
),IllustrationView::UponUpdateInapplicable )
diff --git a/mec_view.cpp b/mec_view.cpp
index 281e132..3ea38d0 100644
--- a/mec_view.cpp
+++ b/mec_view.cpp
@@ -70,8 +70,8 @@ BEGIN_EVENT_TABLE(mec_view, ViewEx)
     EVT_UPDATE_UI(XRCID("print_spreadsheet"    
),mec_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("print_group_roster"   
),mec_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("print_group_quote"    
),mec_view::UponUpdateInapplicable)
-    EVT_UPDATE_UI(XRCID("paste_census_in"      
),mec_view::UponUpdateInapplicable)
-    EVT_UPDATE_UI(XRCID("paste_census_out"     
),mec_view::UponUpdateInapplicable)
+    EVT_UPDATE_UI(XRCID("copy_census"          
),mec_view::UponUpdateInapplicable)
+    EVT_UPDATE_UI(XRCID("paste_census"         
),mec_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("add_cell"             
),mec_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("delete_cells"         
),mec_view::UponUpdateInapplicable)
     EVT_UPDATE_UI(XRCID("column_width_varying" 
),mec_view::UponUpdateInapplicable)
diff --git a/menus.xrc b/menus.xrc
index 6502b0c..7d98283 100644
--- a/menus.xrc
+++ b/menus.xrc
@@ -370,15 +370,15 @@
         <help>Run and print all cells to a group premium quote</help>
     </object>
     <object class="separator"/>
-    <object class="wxMenuItem" name="paste_census_in">
-        <label>Pa_ste census in\tCtrl-Shift-S</label>
-        <bitmap platform="win" stock_id="paste-in"/>
-        <help>Paste census data in from clipboard</help>
-    </object>
-    <object class="wxMenuItem" name="paste_census_out">
-        <label>Pas_te census out\tCtrl-Shift-T</label>
-        <bitmap platform="win" stock_id="paste-out"/>
-        <help>Paste census data out to a spreadsheet file</help>
+    <object class="wxMenuItem" name="copy_census">
+        <label>_Copy census\tCtrl-Shift-C</label>
+        <bitmap platform="win" stock_id="copy-census"/>
+        <help>Copy census data to the clipboard</help>
+    </object>
+    <object class="wxMenuItem" name="paste_census">
+        <label>Pa_ste census\tCtrl-Shift-S</label>
+        <bitmap platform="win" stock_id="paste-census"/>
+        <help>Paste census data from the clipboard</help>
     </object>
     <object class="wxMenuItem" name="add_cell">
         <label>_Add cell\tCtrl-+</label>
diff --git a/paste-in-16.png b/paste-census-16.png
similarity index 100%
rename from paste-in-16.png
rename to paste-census-16.png
diff --git a/paste-in.png b/paste-census.png
similarity index 100%
rename from paste-in.png
rename to paste-census.png
diff --git a/skeleton.cpp b/skeleton.cpp
index 3763696..17658f6 100644
--- a/skeleton.cpp
+++ b/skeleton.cpp
@@ -171,8 +171,8 @@ BEGIN_EVENT_TABLE(Skeleton, wxApp)
     EVT_UPDATE_UI(XRCID("print_spreadsheet"          
),Skeleton::UponUpdateInapplicable           )
     EVT_UPDATE_UI(XRCID("print_group_roster"         
),Skeleton::UponUpdateInapplicable           )
     EVT_UPDATE_UI(XRCID("print_group_quote"          
),Skeleton::UponUpdateInapplicable           )
-    EVT_UPDATE_UI(XRCID("paste_census_in"            
),Skeleton::UponUpdateInapplicable           )
-    EVT_UPDATE_UI(XRCID("paste_census_out"           
),Skeleton::UponUpdateInapplicable           )
+    EVT_UPDATE_UI(XRCID("copy_census"                
),Skeleton::UponUpdateInapplicable           )
+    EVT_UPDATE_UI(XRCID("paste_census"               
),Skeleton::UponUpdateInapplicable           )
     EVT_UPDATE_UI(XRCID("add_cell"                   
),Skeleton::UponUpdateInapplicable           )
     EVT_UPDATE_UI(XRCID("delete_cells"               
),Skeleton::UponUpdateInapplicable           )
     EVT_UPDATE_UI(XRCID("column_width_varying"       
),Skeleton::UponUpdateInapplicable           )
diff --git a/toolbar.xrc b/toolbar.xrc
index 414bc4a..132f1da 100644
--- a/toolbar.xrc
+++ b/toolbar.xrc
@@ -124,15 +124,15 @@
         <longhelp>Run and print all cells to a group premium quote</longhelp>
     </object>
     <object class="separator"/>
-    <object class="tool" name="paste_census_in">
-        <tooltip>Paste census in</tooltip>
-        <bitmap stock_id="paste-in"/>
-        <longhelp>Paste census data in from clipboard</longhelp>
-    </object>
-    <object class="tool" name="paste_census_out">
-        <tooltip>Paste census out</tooltip>
-        <bitmap stock_id="paste-out"/>
-        <longhelp>Paste census data out to a spreadsheet file</longhelp>
+    <object class="tool" name="copy_census">
+        <tooltip>Copy census</tooltip>
+        <bitmap stock_id="copy-census"/>
+        <longhelp>Copy census data to the clipboard</longhelp>
+    </object>
+    <object class="tool" name="paste_census">
+        <tooltip>Paste census</tooltip>
+        <bitmap stock_id="paste-census"/>
+        <longhelp>Paste census data from the clipboard</longhelp>
     </object>
     <object class="tool" name="add_cell">
         <tooltip>Add cell</tooltip>



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/census_view.cpp b/census_view.cpp
index 5bb8e56..e52950b 100644
--- a/census_view.cpp
+++ b/census_view.cpp
@@ -938,8 +938,8 @@ BEGIN_EVENT_TABLE(CensusView, ViewEx)
     EVT_MENU(XRCID("print_spreadsheet"         
),CensusView::UponRunCaseToSpreadsheet   )
     EVT_MENU(XRCID("print_group_roster"        
),CensusView::UponRunCaseToGroupRoster   )
     EVT_MENU(XRCID("print_group_quote"         
),CensusView::UponRunCaseToGroupQuote    )
-    EVT_MENU(XRCID("paste_census_in"           ),CensusView::UponPasteCensusIn 
         )
-    EVT_MENU(XRCID("paste_census_out"          
),CensusView::UponPasteCensusOut         )
+    EVT_MENU(XRCID("copy_census"               ),CensusView::UponCopyCensus    
         )
+    EVT_MENU(XRCID("paste_census"              ),CensusView::UponPasteCensus   
         )
     EVT_MENU(XRCID("add_cell"                  ),CensusView::UponAddCell       
         )
     EVT_MENU(XRCID("delete_cells"              ),CensusView::UponDeleteCells   
         )
     EVT_MENU(XRCID("column_width_varying"      
),CensusView::UponColumnWidthVarying     )
@@ -955,8 +955,8 @@ BEGIN_EVENT_TABLE(CensusView, ViewEx)
     EVT_UPDATE_UI(XRCID("print_spreadsheet"    
),CensusView::UponUpdateAlwaysEnabled    )
     EVT_UPDATE_UI(XRCID("print_group_roster"   
),CensusView::UponUpdateAlwaysEnabled    )
     EVT_UPDATE_UI(XRCID("print_group_quote"    
),CensusView::UponUpdateAlwaysEnabled    )
-    EVT_UPDATE_UI(XRCID("paste_census_in"      
),CensusView::UponUpdateAlwaysEnabled    )
-    EVT_UPDATE_UI(XRCID("paste_census_out"     
),CensusView::UponUpdateColumnValuesVary )
+    EVT_UPDATE_UI(XRCID("copy_census"          
),CensusView::UponUpdateColumnValuesVary )
+    EVT_UPDATE_UI(XRCID("paste_census"         
),CensusView::UponUpdateAlwaysEnabled    )
     EVT_UPDATE_UI(XRCID("add_cell"             
),CensusView::UponUpdateAlwaysEnabled    )
     EVT_UPDATE_UI(XRCID("delete_cells"         
),CensusView::UponUpdateNonemptySelection)
     EVT_UPDATE_UI(XRCID("column_width_varying" 
),CensusView::UponUpdateAlwaysEnabled    )
@@ -1447,15 +1447,15 @@ void 
CensusView::UponUpdateNonemptySelection(wxUpdateUIEvent& e)
     e.Enable(0 < list_window_->GetSelections(selection));
 }
 
-/// Conditionally enable pasting out.
+/// Conditionally enable copying.
 ///
-/// Pasting out is forbidden if it would produce only whitespace; that
-/// is, if no "interesting" column varies across cells. All columns
-/// are interesting except:
+/// Copying is forbidden if it would produce only whitespace; i.e.,
+/// if no "interesting" column varies across cells. All columns are
+/// interesting except:
 ///  - the cell serial number that is always shown in the first column
 ///    (that's just a GUI artifact, not an actual cell datum); and
 ///  - the "UseDOB" and "IssueAge" columns that are filtered out by
-///    DoPasteCensusOut().
+///    DoCopyCensus().
 /// This implementation ignores the first column, then enables the
 /// command unless "UseDOB" is the only other column; the rationale is
 /// clear only in the problem domain: "IssueAge" needn't be tested,
@@ -1694,7 +1694,7 @@ void CensusView::UponRunCaseToGroupQuote(wxCommandEvent&)
 /// file are assumed to represent user intention). In this case,
 /// pasted data is appended to the cells that were already present.
 
-void CensusView::UponPasteCensusIn(wxCommandEvent&)
+void CensusView::UponPasteCensus(wxCommandEvent&)
 {
     std::string const census_data = ClipboardEx::GetText();
 
@@ -1868,11 +1868,11 @@ void CensusView::UponPasteCensusIn(wxCommandEvent&)
 
 /// Paste from the census manager into a "spreadsheet" (TSV) file.
 ///
-/// Simply calls DoPasteCensusOut(), q.v.
+/// Simply calls DoCopyCensus(), q.v.
 
-void CensusView::UponPasteCensusOut(wxCommandEvent&)
+void CensusView::UponCopyCensus(wxCommandEvent&)
 {
-    DoPasteCensusOut();
+    DoCopyCensus();
 }
 
 /// Paste from the census manager into a "spreadsheet" (TSV) file.
@@ -1885,7 +1885,7 @@ void CensusView::UponPasteCensusOut(wxCommandEvent&)
 /// data from lmi, manipulating it in a spreadsheet, and then pasting
 /// it back into lmi.
 ///
 /// Never extract "UseDOB": it's always set by UponPasteCensusIn().
 /// Never extract "IssueAge". If it's present, then "UseDOB" must also
 /// be, and "UseDOB" preserves information that "IssueAge" loses.
 ///
@@ -1896,10 +1896,10 @@ void CensusView::UponPasteCensusOut(wxCommandEvent&)
 /// expected; thus, they end in "'t\n". This makes the code slightly
 /// simpler by avoiding a "loop and a half". In practice, it doesn't
 /// make any difference: gnumeric, libreoffice calc, a popular msw
 /// spreadsheet program, and lmi's own UponPasteCensusIn() all ignore
 /// the extra '\t'.
 
-void CensusView::DoPasteCensusOut() const
+void CensusView::DoCopyCensus() const
 {
     Timer timer;
     std::vector<std::string> distinct_headers;
@@ -1915,12 +1915,12 @@ void CensusView::DoPasteCensusOut() const
 
     if(distinct_headers.empty())
         {
-        alarum() << "All cells identical: nothing to paste out." << LMI_FLUSH;
+        alarum() << "All cells identical: nothing to copy." << LMI_FLUSH;
         }
 
     configurable_settings const& c = configurable_settings::instance();
     std::string const& e = c.spreadsheet_file_extension();
-    std::string const  f = fs::basename(base_filename()) + ".pasted_out.cns";
+    std::string const  f = fs::basename(base_filename()) + ".census.cns";
     std::string file_name = unique_filepath(f, e).string();
     std::ofstream ofs(file_name.c_str(), ios_out_app_binary());
 
@@ -1956,5 +1956,5 @@ void CensusView::DoPasteCensusOut() const
     std::string s;
     istream_to_string(ifs, s);
     ClipboardEx::SetText(s);
-    status() << "Paste out: " << timer.stop().elapsed_msec_str() << std::flush;
+    status() << "Copy: " << timer.stop().elapsed_msec_str() << std::flush;
 }
@@ -1885,7 +1885,7 @@ void CensusView::UponPasteCensusOut(wxCommandEvent&)
 /// it back into lmi.
 ///
-/// Never extract "UseDOB": it's always set by UponPasteCensusIn().
+/// Never extract "UseDOB": it's always set by UponPasteCensus().
 /// Never extract "IssueAge". If it's present, then "UseDOB" must also
 /// be, and "UseDOB" preserves information that "IssueAge" loses.
@@ -1896,10 +1896,10 @@ void CensusView::UponPasteCensusOut(wxCommandEvent&)
 /// simpler by avoiding a "loop and a half". In practice, it doesn't
 /// make any difference: gnumeric, libreoffice calc, a popular msw
-/// spreadsheet program, and lmi's own UponPasteCensusIn() all ignore
+/// spreadsheet program, and lmi's own UponPasteCensus() all ignore
 /// the extra '\t'.
 